Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(142)

Unified Diff: src/core/SkBitmapCache.h

Issue 1320513005: simplify bitmap scaler and cache (Closed) Base URL: https://skia.googlesource.com/skia.git@master
Patch Set: Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/core/SkBitmapCache.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/core/SkBitmapCache.h
diff --git a/src/core/SkBitmapCache.h b/src/core/SkBitmapCache.h
index 3e541eed2c57f7c2d54bd5142fa72d7ae9c27e26..12be6fad359006e49a0c60aaee9732977c233438 100644
--- a/src/core/SkBitmapCache.h
+++ b/src/core/SkBitmapCache.h
@@ -27,17 +27,17 @@ public:
static SkBitmap::Allocator* GetAllocator();
/**
* Search based on the src bitmap and inverse scales in X and Y. If found, returns true and
* result will be set to the matching bitmap with its pixels already locked.
*/
- static bool Find(const SkBitmap& src, SkScalar invScaleX, SkScalar invScaleY, SkBitmap* result,
- SkResourceCache* localCache = nullptr);
+ static bool FindWH(const SkBitmap& src, int width, int height, SkBitmap* result,
+ SkResourceCache* localCache = nullptr);
/*
* result must be marked isImmutable()
*/
- static void Add(const SkBitmap& src, SkScalar invScaleX, SkScalar invScaleY,
- const SkBitmap& result, SkResourceCache* localCache = nullptr);
+ static void AddWH(const SkBitmap& src, int width, int height, const SkBitmap& result,
+ SkResourceCache* localCache = nullptr);
/**
* Search based on the bitmap's genID and subset. If found, returns true and
« no previous file with comments | « no previous file | src/core/SkBitmapCache.cpp » ('j') | no next file with comments »
@@ -27,17 +27,17 @@ public:
static SkBitmap::Allocator* GetAllocator();
/**
- * Search based on the src bitmap and inverse scales in X and Y. If found, returns true and
+ * Search based on the src bitmap and scaled width/height. If found, returns true and
* result will be set to the matching bitmap with its pixels already locked.
*/

Powered by Google App Engine
This is Rietveld 408576698